@@ -13,6 +13,12 @@
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 
+#include <config.h>
+
+#ifdef GNOKII_GCONF
+#include "gnokii-gconf.h"
+#endif
+
 #include "contactinfos.h"
 #include "client-contactinfos-dbus.h"
 #include "marshall.h"
@@ -141,7 +147,7 @@ void oneResultSignal_cb(
 	GtkTreeIter iter;
 	gchar *text;
 					
-	if (retCode = CI_NOT_FOUND) {
+	if (retCode == CI_NOT_FOUND) {
 		text = g_strdup_printf(_("ContactInfos found nothing for %s"), (gchar *) gtk_entry_get_text(GTK_ENTRY(uic->searchEntry)));
 		hildon_banner_show_information(GTK_WIDGET(gtk_widget_get_toplevel(uic->searchEntry)), GTK_STOCK_DIALOG_INFO, text);
 		g_free(text);
@@ -176,6 +182,16 @@ void on_menu_quit(GtkMenuItem * menuitem, UIComponents *uic) {
 	quit_event( uic, 0, NULL);
 }
 
+void on_menu_about(GtkMenuItem * menuitem, UIComponents *uic) {
+	gtk_show_about_dialog(GTK_WIDGET(gtk_widget_get_toplevel(menuitem)),
+		"version", VERSION,
+		"website", "https://garage.maemo.org/projects/phonelink/",
+		"website-label", _("Garage Page @ Maemo"),
+		"authors", g_strsplit("Fred Lef\xc3\xa9v\xc3\xa8re-Laoide\n", "\n", -1),
+		"logo", gdk_pixbuf_new_from_file(ICONFILE, NULL),
+		NULL);
+}
+
 void on_menu_transform(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
 	uic->transformPlus = !(uic->transformPlus);
 }
@@ -209,6 +225,17 @@ GtkMenu *create_menus(UIComponents *uic) {
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuItem), uic->transformPlus);
 	gtk_menu_append(menuGroup, menuItem);
 	
+	menuGroup = gtk_menu_new();
+	menuItem = gtk_menu_item_new_with_label (_("Help"));
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuItem), menuGroup);
+	gtk_menu_append(menuBar, menuItem);
+	
+	menuItem = gtk_image_menu_item_new_with_label (_("About ..."));
+	image = gtk_image_new_from_stock (GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem), image);
+	g_signal_connect (G_OBJECT (menuItem), "activate", G_CALLBACK (on_menu_about), (gpointer) uic);
+	gtk_menu_append(menuGroup, menuItem);
+	
 	return GTK_MENU(menuBar);
 }
 
@@ -660,6 +687,8 @@ static void sendSMS (gchar *number, gchar *text) {
 	 * 	   255 * 153 = 39015 default alphabet characters */
 	int input_len, i, curpos = 0;
 
+	g_printf("sendSMS(number = %s, text = %s)\n", number, text);
+	
 	input_len = GN_SMS_MAX_LENGTH;
 
 	/* The memory is zeroed here */
@@ -680,7 +709,7 @@ static void sendSMS (gchar *number, gchar *text) {
 		sms.smsc.type = data.message_center->smsc.type;
 	} else {
 		g_print("Cannot read the SMSC number from your phone. If the sms send will fail, please use --smsc option explicitely giving the number.\n");
-																			}
+	}
 	free(data.message_center);
 
 	if (!sms.smsc.type) sms.smsc.type = GN_GSM_NUMBER_Unknown;
@@ -801,6 +830,11 @@ int main( int argc, char *argv[] ) {
 	GtkWidget *smsTextView;
 	GtkTextBuffer *buffer;
 	GConfClient *gconf_client = NULL;
+	gboolean gnokiiFile = FALSE;
+	
+#ifdef GNOKII_GCONF
+	gchar ** gnokiiCfg;
+#endif	
 	
 	HildonProgram *app;
 	HildonWindow *appview;
@@ -829,24 +863,32 @@ int main( int argc, char *argv[] ) {
 	hildon_window_set_menu (appview, create_menus (uic));
 
 /* Gnokii : read the config */
-/*	if (gn_cfg_read(&bindir) < 0) {
-		 hildon_banner_show_information(GTK_WIDGET(appview), NULL, "gnokii rc file reading problem\n");
-	} else {
-		if (!gn_cfg_phone_load("", state)) {
-			 hildon_banner_show_information(GTK_WIDGET(appview), NULL, "gnokki rc file loading problem\n");
+	gn_error err;
+#ifdef GNOKII_GCONF
+	gnokiiCfg = getGnokiiCfg(NULL);
+	gnokiiFile = TRUE;
+	state = g_new0(struct gn_statemachine,1);
+	if ((err = gn_cfg_memory_read ((char **)gnokiiCfg)) != GN_ERR_NONE) {
+		hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("Error reading gnokii configuration %s\n%s\n%s\n%s\n%s"), gn_error_print(err), gnokiiCfg[0], gnokiiCfg[1], gnokiiCfg[2], gnokiiCfg[3]);
+		gnokiiFile = FALSE;
+	} else if ((err = gn_cfg_phone_load(NULL, state)) != GN_ERR_NONE) {
+		fprintf(stderr, "%s\n", gn_error_print(err));
+		hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("gn_cfg_phone_load %s"), gn_error_print(err));
+		gnokiiFile = FALSE;
+	}
+#endif
+	if (!gnokiiFile) {
+		if ((err = gn_lib_phoneprofile_load(NULL, &state)) != GN_ERR_NONE) {
+			fprintf(stderr, "%s\n", gn_error_print(err));
+			hildon_banner_show_information(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR,  gn_error_print(err));
 		}
 	}
-*/
-	gn_error err;
-	if ((err = gn_lib_phoneprofile_load(NULL, &state)) != GN_ERR_NONE) {
-		fprintf(stderr, "%s\n", gn_error_print(err));
-		hildon_banner_show_information(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR,  gn_error_print(err));
-	}
+
 	
 	g_print("avant osso init\n");
 
 	/* Initialize maemo application */
-	uic->osso_context = osso_initialize(APPLICATION_DBUS_SERVICE, "0.5", FALSE, NULL);
+	uic->osso_context = osso_initialize(APPLICATION_DBUS_SERVICE, VERSION, FALSE, NULL);
 
 	g_print("apres osso_init\n");
 	            
@@ -922,7 +964,6 @@ int main( int argc, char *argv[] ) {
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 
 	smsTextView = gtk_text_view_new();
-	gtk_container_add(GTK_CONTAINER(scrolled_window), smsTextView);
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(smsTextView), GTK_WRAP_WORD_CHAR);
 	
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(smsTextView));
@@ -932,6 +973,8 @@ int main( int argc, char *argv[] ) {
 
 	uic->sigId = g_signal_connect (G_OBJECT (smsTextView), "focus-in-event", G_CALLBACK (clearSMSTextView_cb), (gpointer) uic);
 
+	gtk_container_add(GTK_CONTAINER(scrolled_window), smsTextView);
+
 	gtk_table_attach_defaults( GTK_TABLE(table), scrolled_window, 0, 5, 4, 9);
 	
 	gtk_widget_show_all (GTK_WIDGET(appview));
